@@ -58,9 +58,15 @@ gable data-asset check --source-type protobuf --files ./**/*.proto""",
     
     For databases (postgres, mysql, mssql) the check will be performed for all tables within the database.
 
-    For protobuf/avro/json_schema the check will be performed for all file(s)
+    For protobuf/avro the check will be performed for all file(s)
     """,
 )
+@click.option(
+    "--include-unchanged-assets",
+    type=bool,
+    default=False,
+    help="""Include assets that are the same as Gable's registered version of the asset. This is useful for checking the current state of an asset but should not be used for automated checks on branches.""",
+)
 @click.option(
     "-o",
     "--output",
@@ -79,7 +85,7 @@ gable data-asset check --source-type protobuf --files ./**/*.proto""",
     action="check",
 )
 @file_source_type_options(
-    option_group_help_text="""Options for checking Protobuf message(s), Avro record(s), or JSON schema object(s) for contract violations.""",
+    option_group_help_text="""Options for checking Protobuf message(s) or Avro record(s) for contract violations.""",
     action="check",
 )
 @python_project_options(
@@ -127,6 +133,7 @@ gable data-asset check --source-type protobuf --files ./**/*.proto""",
 def check_data_asset(
     ctx: ClickContext,
     source_type: SourceType,
+    include_unchanged_assets: bool,
     output: str,
     host: str,
     port: int,
@@ -147,6 +154,7 @@ def check_data_asset(
     event_name_key: str,
     emitter_file_path: str,
     library: Optional[str],
+    node_modules_include: Optional[str],
     spark_job_entrypoint: Optional[str],
     connection_string: Optional[str],
     metastore_connection_string: Optional[str],
@@ -205,6 +213,7 @@ def check_data_asset(
             ctx.obj.client,
             response_type,
             source_type,
+            include_unchanged_assets,
             source_names,
             db,
             schema,
@@ -237,6 +246,7 @@ def check_data_asset(
             ctx.obj.client,
             response_type,
             source_type,
+            include_unchanged_assets,
             source_names,
             db,
             schema,
@@ -259,6 +269,7 @@ def check_data_asset(
         results = check_compliance_typescript_data_asset(
             ctx,
             library,
+            node_modules_include,
             project_root,
             emitter_file_path,
             emitter_function,
@@ -266,6 +277,7 @@ def check_data_asset(
             emitter_name_parameter,
             event_name_key,
             response_type,
+            include_unchanged_assets,
         )
     elif source_type == SourceType.pyspark:
         if not project_root or not (
@@ -291,6 +303,7 @@ def check_data_asset(
             csv_schema_file,
             csv_path_to_table_file,
             response_type,  # type: ignore
+            include_unchanged_assets,
         )
     elif source_type == SourceType.s3:
         from gable.cli.helpers.data_asset_s3 import check_compliance_s3_data_assets
@@ -310,6 +323,7 @@ def check_data_asset(
             include_prefix,
             exclude_prefix,
             skip_profiling,
+            include_unchanged_assets,
         )
     else:
         raise click.ClickException(
