@@ -1,13 +1,17 @@
 import glob
 import json
 import os
+import platform
 import shutil
 import subprocess
-from typing import Any, Optional, Union
+import tempfile
+from typing import Any, List, Optional, Union
 
 import click
+import gable.cli.helpers.sca_exceptions as sca_exceptions
 from gable.api.client import GableAPIClient
 from gable.cli.helpers.auth import set_npm_config_credentials
+from gable.openapi import CreateTelemetryRequest, TelemetryType
 from loguru import logger
 
 BASE_NPX_CMD = [
@@ -91,16 +95,18 @@ def run_sca_pyspark(
         )
         if result.returncode != 0:
             logger.debug(result.stderr)
-            raise click.ClickException(f"Error running Gable SCA: {result.stderr}")
+            raise click.ClickException(result.stdout)
         logger.debug(result.stdout)
         logger.trace(result.stderr)
         # The sca CLI prints the results to stdout,and everything else to trace/warn/debug/error
         return result.stdout
     except Exception as e:
         logger.opt(exception=e).debug("Error running Gable SCA")
-        raise click.ClickException(
-            "Error running Gable SCA: Please ensure you have the @gable-eng/sca package installed."
-        )
+        sca_e = sca_exceptions.create_pyspark_exception(e)
+        if sca_e is not None:
+            logger.info(str(sca_e.markdown))
+            raise sca_e
+        raise click.ClickException("Error running Gable SCA: \n\n" + str(e))
 
 
 def run_sca_python(
@@ -153,13 +159,14 @@ def run_sca_python(
 
 def run_sca_typescript(
     library: Optional[str],
+    node_modules_include: Optional[str],
     project_root: str,
     emitter_file_path: Optional[str],
     emitter_function: Optional[str],
     emitter_payload_parameter: Optional[str],
     event_name_key: Optional[str],
     event_name_parameter: Optional[str],
-    api_endpoint: Union[str, None] = None,
+    client: GableAPIClient,
 ) -> tuple[str, dict[str, dict[str, Any]]]:
     try:
         if library:
@@ -178,10 +185,16 @@ def run_sca_typescript(
             else:
                 options += ["--event-name-parameter", event_name_parameter]
 
+        if node_modules_include:
+            options += ["--node-modules-include", node_modules_include]
+
         cmd = get_sca_cmd(
-            api_endpoint,
+            client.endpoint,
             ["typescript", project_root] + options,
         )
+        sca_prime_shadow_results_future = start_sca_prime_shadow(
+            client, project_root, []
+        )
         result = subprocess.run(
             cmd,
             stdout=subprocess.PIPE,
@@ -195,7 +208,9 @@ def run_sca_typescript(
         logger.debug(result.stderr)
 
         # Run sca-prime in shadow-mode
-        shadow_results = run_sca_prime_shadow(api_endpoint)
+        shadow_results, _ = get_sca_prime_shadow_results(
+            sca_prime_shadow_results_future, client, project_root, True
+        )
         # The sca CLI prints the results to stdout,and everything else to trace/warn/debug/error
         return (result.stdout, shadow_results)
     except Exception as e:
@@ -280,47 +295,186 @@ def get_installed_package_dir() -> str:
     raise Exception("SCA package not found in npx cache")
 
 
-def run_sca_prime_shadow(
-    gable_api_endpoint: Union[str, None]
-) -> dict[str, dict[str, Any]]:
+def start_sca_prime_shadow(
+    client: GableAPIClient,
+    project_root: str,
+    annotations: List[str],
+    sca_debug: bool = False,
+    semgrep_bin_path: Optional[str] = None,
+) -> Union[tuple[subprocess.Popen, str], None]:
+    # return process and tempdir if no error, else None
+    if os.environ.get("ENABLE_SCA_PRIME_SHADOW", "true").lower() != "true":
+        return None
+
+    os.environ["SEMGREP_DEPLOY_CORE_BIN_PATH"] = semgrep_bin_path or ""
+
     try:
-        if "SCA_PRIME_FINDINGS_FILE" not in os.environ:
-            return {}
-        logger.debug("Running Gable Code in shadow mode")
-        sca_prime_path = _get_sca_prime_path(gable_api_endpoint)
-        out_file = os.path.expanduser(os.environ["SCA_PRIME_FINDINGS_FILE"])
+        logger.debug("Running SCA Prime in shadow mode")
+        sca_prime_path = _get_sca_prime_path(client.endpoint)
+
+        if not sca_prime_path:
+            logger.error("SCA Prime path not found")
+            return None
+
+        temp_dir = tempfile.mkdtemp()
+        command = [
+            sca_prime_path,
+            "run",
+            "--project-root",
+            project_root,
+            "--output-type",
+            "fs",
+            "--output-path",
+            temp_dir,
+        ]
+        if annotations:
+            command += ["--annotations"]
+            command += annotations
+        if sca_debug:
+            command += ["--debug"]
+
+        process = subprocess.Popen(
+            command,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            env=os.environ,
+            text=True,
+        )
+        return (process, temp_dir)
+    except Exception as e:
+        logger.opt(exception=e).debug(f"Error running SCA Prime in shadow mode {e}", e)
+        return None
+
+
+def run_sca_npx_help(
+    api_endpoint: Union[str, None] = None,
+):
+    """
+    Implicitly checks to see if @gable-eng/sca is installed
+    """
+    try:
+        cmd = get_sca_cmd(
+            api_endpoint,
+            ["--help"],
+        )
         result = subprocess.run(
-            [sca_prime_path, "--mock-data-output-file", out_file],
+            cmd,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             text=True,
         )
-        if result.returncode != 0:
-            logger.debug(result.stderr)
-            raise Exception(f"Error running SCA prime in shadow mode: {result.stderr}")
-        logger.debug(result.stdout)
-        logger.trace(result.stderr)
-        with open(out_file, "r") as f:
-            findings = json.load(f)["findings"]
-            recap_results = [finding["recap"] for finding in findings]
+
+    except Exception as e:
+        logger.opt(exception=e).debug("Error running Gable SCA")
+        raise click.ClickException(
+            "Error running Gable SCA: Please ensure you have the @gable-eng/sca package installed."
+        )
+
+
+def get_sca_prime_shadow_results(
+    sca_prime_process_data: Union[tuple[subprocess.Popen, str], None],
+    client: GableAPIClient,
+    project_root: str,
+    post_metrics=True,
+) -> tuple[dict[str, dict[str, Any]], dict]:
+    if sca_prime_process_data is None:
+        return {}, {}
+    sca_prime_process, temp_dir = sca_prime_process_data
+    try:
+        stdout, stderr = sca_prime_process.communicate()
+        logger.trace("--------------------SCA PRIME STDOUT-------------------")
+        logger.trace(stdout)
+        logger.trace("--------------------SCA PRIME STDERR-------------------")
+        logger.trace(stderr)
+        logger.trace("-------------------------------------------------------")
+
+        if post_metrics:
+            metrics_file = os.path.join(temp_dir, "metrics.json")
+            if os.path.exists(metrics_file):
+                with open(metrics_file, "r") as f:
+                    metrics = json.load(f)
+                    logger.debug(f"Posting metrics from sca-prime: {metrics}")
+                    post_metrics_request = CreateTelemetryRequest(
+                        id=None,
+                        data=metrics,
+                        type=TelemetryType(__root__="SCA_PRIME"),
+                    )
+                    post_metrics_response, post_metrics_success = client.post_telemetry(
+                        post_metrics_request
+                    )
+                    if post_metrics_success:
+                        logger.debug(
+                            f"Posted metrics from sca-prime: {post_metrics_response}"
+                        )
+                    else:
+                        logger.error(
+                            f"Error posting metrics from sca-prime: {post_metrics_response}"
+                        )
+            else:
+                logger.error("SCA prime generated metrics file not found")
+
+        findings_file = os.path.join(temp_dir, "findings.json")
+
+        if not os.path.exists(findings_file):
+            logger.debug("SCA prime generated findings file not found")
+            return {}, {}
+
+        with open(findings_file, "r") as f:
+            all_findings = json.load(f)["findings"]
+
+            location_results = {
+                f'{finding["recap"]["name"]}': (
+                    finding["recap"],
+                    finding["source_location"],
+                )
+                for finding in all_findings
+            }
+
+            recap_results = [finding["recap"] for finding in all_findings]
             dict_result = {
-                f'PRIME_{recap_struct["name"]}': recap_struct
+                f'{recap_struct["name"]}': recap_struct
                 for recap_struct in recap_results
             }
+
             logger.debug(f"Results from sca-prime: {dict_result}")
-            return dict_result
+            return dict_result, location_results
+
     except Exception as e:
-        logger.opt(exception=e).debug("Error running Gable Code in shadow mode", e)
-        return {}
+        logger.opt(exception=e).debug(f"Error running SCA Prime in shadow mode {e}", e)
+        return {}, {}
+    finally:
+        shutil.rmtree(temp_dir)
 
 
-def _get_sca_prime_path(gable_api_endpoint: Union[str, None]) -> str:
+def _get_sca_prime_path(gable_api_endpoint: Union[str, None]) -> Union[str, None]:
     """Returns the path to SCA prime"""
+    architecture = _get_host_architecture_for_sca_prime_binary()
     if should_use_local_sca(gable_api_endpoint):
         # Needs to be a dynamic import because this file is excluded from the bundled package
         from gable.cli.local import get_local_sca_prime
 
-        local_sca_prime = get_local_sca_prime()
-        logger.trace(f"Using local SCA prime: {local_sca_prime}")
+        local_sca_prime = get_local_sca_prime(architecture)
+        logger.debug(f"Using local SCA prime: {local_sca_prime}")
         return local_sca_prime
-    return os.path.join(get_installed_package_dir(), "dist/sca-prime")
+    return os.path.join(
+        get_installed_package_dir(),
+        "dist",
+        "sca-prime",
+        f"sca-prime-{architecture}",
+        "sca-prime",
+    )
+
+
+def _get_host_architecture_for_sca_prime_binary() -> str:
+    """Returns the host architecture for the current system as a valid rust target"""
+    result = "x86_64-unknown-linux-gnu"
+    if platform.system() == "Darwin":
+        result = "aarch64-apple-darwin"
+    elif platform.system() == "Linux":
+        result = "x86_64-unknown-linux-gnu"
+    else:
+        logger.error(
+            f"Unsupported platform: {platform.system()}, using default: {result}"
+        )
+    logger.trace(f"Host architecture for sca-prime binary: {result}")
+    return result
