@@ -1,7 +1,13 @@
+import json
 from typing import Any, List, Tuple, Union
 
+import pydantic
 from gable.api.client import GableAPIClient
-from gable.openapi import GableSchemaContractField, PostContractRequest
+from gable.openapi import (
+    GableSchemaContractField,
+    PostContractRequest,
+    PostContractResponse,
+)
 from gable.sdk.converters.trino import (
     convert_trino_timestamp_to_spark_timestamp,
     trino_to_gable_type,
@@ -31,25 +37,25 @@ class GableContract:
         # Currently, the behavior is either all contracts are published or none are (if there is one invalid contract)
         # Ideally, we can refactor this code and the API to allow for partial success in the future
 
-        if not success or not isinstance(api_response, dict):
+        if not success or not isinstance(api_response, PostContractResponse):
             failure_message = (
-                api_response["message"]
-                if isinstance(api_response, dict)
+                api_response.message
+                if isinstance(api_response, PostContractResponse)
                 else "Unknown error"
             )
             return ContractPublishResponse(
                 success=False, updatedContractIds=[], message=failure_message
             )
         else:
-            updated_contract_ids = api_response["contractIds"]
+            updated_contract_ids = api_response.contractIds
             return ContractPublishResponse(
                 success=True,
                 updatedContractIds=updated_contract_ids,
-                message=api_response["message"],
+                message=api_response.message,
             )
 
+    @staticmethod
     def trino_to_gable_schema(
-        self,
         dict_schema: dict[
             str, Union[str, Union[TrinoDataType, Tuple[TrinoDataType, Tuple[Any, ...]]]]
         ],
@@ -63,3 +69,21 @@ class GableContract:
                 convert_trino_timestamp_to_spark_timestamp(result) for result in results
             ]
         return results
+
+    @staticmethod
+    def json_schema_to_gable_schema(
+        schema: Union[str, dict[str, Any]],
+    ) -> List[GableSchemaContractField]:
+        import recap
+        import recap.types
+        from recap.converters.json_schema import JSONSchemaConverter
+
+        # JSONSchemaConverter expects a string, so serialize if it's a dict
+        if isinstance(schema, dict):
+            schema = json.dumps(schema)
+        converter = JSONSchemaConverter()
+
+        return [
+            pydantic.parse_obj_as(GableSchemaContractField, recap.types.to_dict(o))
+            for o in converter.to_recap(schema).fields
+        ]
